@@ -1,6 +1,6 @@
-nawk '
-  /^d k/ { print $5 - $3 }
-' | sort -n | nawk '
+awk '/^d k/ { print $5 - $3 }' \
+| sort -n \
+| awk '
   { x += 1; cumulative[$1] = x }
   END {
     if (x > 0) {
@@ -19,8 +19,11 @@ nawk '
         nd += numdel[p]
         if (p >= 10)
 	  if (nd > 0)
-            if (mindel[p] >= 0)
-              print sprintf("%.2f",mindel[p]), sprintf("%.2f",td / nd), p
+            if (mindel[p] >= 0) {
+	      str1 = sprintf("%.2f",mindel[p])
+	      str2 = sprintf("%.2f",td / nd)
+	      print str1, str2, p
+	    }
       }
     }
   }
