@@ -1,4 +1,4 @@
-nawk '
+awk '
   /^m/ {
     sender = $10"/"$8
     messages[sender] += 1
@@ -11,11 +11,12 @@ nawk '
   }
   /^d/ {
     sender = $10"/"$7
-    xdelay[sender] += ($5 - $4)
+    xdelay[sender] += $5 - $4
   }
   END {
     for (sender in messages) {
-      print messages[sender],mbytes[sender],sbytes[sender],rbytes[sender],succ[sender] + fail[sender],succ[sender] + fail[sender] + temp[sender],sprintf("%.6f",xdelay[sender]),sender
+      str = sprintf("%.6f",xdelay[sender])
+      print messages[sender],mbytes[sender],sbytes[sender],rbytes[sender],succ[sender] + fail[sender],succ[sender] + fail[sender] + temp[sender],str,sender
     }
   }
 '
