@@ -1,4 +1,4 @@
-nawk '
+awk '
   /^m/ {
     uid = $10
     messages[uid] += 1
@@ -11,11 +11,12 @@ nawk '
   }
   /^d/ {
     uid = $10
-    xdelay[uid] += ($5 - $4)
+    xdelay[uid] += $5 - $4
   }
   END {
     for (uid in messages) {
-      print messages[uid],mbytes[uid],sbytes[uid],rbytes[uid],succ[uid] + fail[uid],succ[uid] + fail[uid] + temp[uid],sprintf("%.6f",xdelay[uid]),uid
+      str = sprintf("%.6f",xdelay[uid])
+      print messages[uid],mbytes[uid],sbytes[uid],rbytes[uid],succ[uid] + fail[uid],succ[uid] + fail[uid] + temp[uid],str,uid
     }
   }
 '
