@@ -4,4 +4,4 @@ Meaning of each line: The first pct% of successful deliveries
 all happened within doneby seconds. The average ddelay was avg.
 '
 ( echo doneby avg pct
-BIN/ddist ) | BIN/columnt
+HOME/bin/ddist ) | HOME/bin/columnt
