@@ -7,4 +7,4 @@ One line per recipient. Information on each line:
 * xdelay is the total xdelay incurred by this recipient.
 '
 ( echo sbytes mess tries xdelay recipient
-BIN/recipients | sort +4 ) | BIN/columnt
+HOME/bin/recipients | sort +4 ) | HOME/bin/columnt
