@@ -7,4 +7,4 @@ One line per recipient host. Information on each line:
 * xdelay is the total xdelay incurred by this host.
 '
 ( echo sbytes mess tries xdelay host
-BIN/rhosts | sort +4 ) | BIN/columnt
+HOME/bin/rhosts | sort +4 ) | HOME/bin/columnt
