@@ -5,4 +5,4 @@ One line per recipient, sorted by avg. Information on each line:
 * tries is the number of deliveries that avg is based on.
 '
 ( echo avg tries recipient
-BIN/recipients | BIN/rxdelay ) | BIN/columnt
+HOME/bin/recipients | HOME/bin/rxdelay ) | HOME/bin/columnt
