@@ -10,4 +10,4 @@ One line per sender. Information on each line:
 * xdelay is the total xdelay incurred by this sender.
 '
 ( echo mess bytes sbytes rbytes recips tries xdelay sender
-BIN/senders | sort -n +7 ) | BIN/columnt
+HOME/bin/senders | sort -n +7 ) | HOME/bin/columnt
