@@ -10,4 +10,4 @@ One line per sender uid. Information on each line:
 * xdelay is the total xdelay incurred by this uid.
 '
 ( echo mess bytes sbytes rbytes recips tries xdelay uid
-BIN/suids | sort -n +7 ) | BIN/columnt
+HOME/bin/suids | sort -n +7 ) | HOME/bin/columnt
